from django.apps import AppConfig


class PageConfig(AppConfig):
    name = "page"
